@@ -23,3 +23,8 @@ class BaseModel:
             # which does not have a scenario.description attribute.
             return getattr(self._data, key, None)
         return getattr(self._data, key)
+
+    @property
+    def exists(self) -> bool:
+        """Return True if the feature exists."""
+        return self._data is not None
